@@ -80,6 +80,11 @@ func (s Scanner) Scan(ctx context.Context, target, artifactKey string, blobKeys
 	case errors.Is(err, analyzer.ErrUnknownOS):
 		log.Logger.Debug("OS is not detected.")
 
+		// Packages may contain OS-independent binary information even though OS is not detected.
+		if len(artifactDetail.Packages) != 0 {
+			artifactDetail.OS = &ftypes.OS{Family: "none"}
+		}
+
 		// If OS is not detected and repositories are detected, we'll try to use repositories as OS.
 		if artifactDetail.Repository != nil {
 			log.Logger.Debugf("Package repository: %s %s", artifactDetail.Repository.Family, artifactDetail.Repository.Release)
@@ -118,9 +123,9 @@ func (s Scanner) Scan(ctx context.Context, target, artifactKey string, blobKeys
 			artifactDetail.OS.Eosl = eosl
 		}
 		// Merge package results into vulnerability results
-		s.fillPkgsInVulns(pkgResults, vulnResults)
+		mergedResults := s.fillPkgsInVulns(pkgResults, vulnResults)
 
-		results = append(results, vulnResults...)
+		results = append(results, mergedResults...)
 	} else {
 		// If vulnerability scanning is not enabled, it just adds package results.
 		results = append(results, pkgResults...)
@@ -167,12 +172,10 @@ func (s Scanner) Scan(ctx context.Context, target, artifactKey string, blobKeys
 }
 
 func (s Scanner) osPkgsToResult(target string, detail ftypes.ArtifactDetail, options types.ScanOptions) *types.Result {
-	if len(detail.Packages) == 0 {
+	if len(detail.Packages) == 0 || detail.OS == nil {
 		return nil
 	}
-	if detail.OS != nil {
-		target = fmt.Sprintf("%s (%s %s)", target, detail.OS.Family, detail.OS.Name)
-	}
+
 	pkgs := detail.Packages
 	if options.ScanRemovedPackages {
 		pkgs = mergePkgs(pkgs, detail.HistoryPackages)
@@ -181,7 +184,7 @@ func (s Scanner) osPkgsToResult(target string, detail ftypes.ArtifactDetail, opt
 		return strings.Compare(pkgs[i].Name, pkgs[j].Name) <= 0
 	})
 	return &types.Result{
-		Target:   target,
+		Target:   fmt.Sprintf("%s (%s %s)", target, detail.OS.Family, detail.OS.Name),
 		Class:    types.ClassOSPkg,
 		Type:     detail.OS.Family,
 		Packages: pkgs,
@@ -312,15 +315,22 @@ func (s Scanner) scanLangPkgs(apps []ftypes.Application) (types.Results, error)
 	return results, nil
 }
 
-func (s Scanner) fillPkgsInVulns(pkgResults, vulnResults types.Results) {
-	// Fill vulnerability results in package results
-	for i := range vulnResults {
-		if r, found := lo.Find(pkgResults, func(r types.Result) bool {
-			return r.Class == vulnResults[i].Class && r.Target == vulnResults[i].Target
+func (s Scanner) fillPkgsInVulns(pkgResults, vulnResults types.Results) types.Results {
+	var results types.Results
+	if len(pkgResults) == 0 { // '--list-all-pkgs' == false or packages not found
+		return vulnResults
+	}
+	for _, result := range pkgResults {
+		if r, found := lo.Find(vulnResults, func(r types.Result) bool {
+			return r.Class == result.Class && r.Target == result.Target
 		}); found {
-			vulnResults[i].Packages = r.Packages
+			r.Packages = result.Packages
+			results = append(results, r)
+		} else { // when package result has no vulnerabilities we still need to add it to result(for 'list-all-pkgs')
+			results = append(results, result)
 		}
 	}
+	return results
 }
 
 func (s Scanner) misconfsToResults(misconfs []ftypes.Misconfiguration) types.Results {
@@ -480,6 +490,7 @@ func toDetectedMisconfiguration(res ftypes.MisconfResult, defaultSeverity dbType
 
 	return types.DetectedMisconfiguration{
 		ID:          res.ID,
+		AVDID:       res.AVDID,
 		Type:        res.Type,
 		Title:       res.Title,
 		Description: res.Description,
